@@ -1,14 +1,11 @@
 __all__ = [
-    "ABC",
-    "Path",
     "Any",
     "Type",
+    "Path",
     "Dict",
     "List",
     "Union",
     "Tuple",
-    "Deque",
-    "AnyStr",
     "Number",
     "Literal",
     "Sequence",
@@ -16,25 +13,20 @@ __all__ = [
     "Callable",
     "PathLike",
     "TypeAlias",
-    "abstractmethod",
 ]
 
-from abc import ABC, abstractmethod
-
 from typing import (
     Any,
     Dict,
     List,
     Tuple,
     Type,
-    Deque,
     Union,
     Literal,
     Sequence,
     Optional,
     Callable,
     TypeAlias,
-    AnyStr,
 )
 from numbers import Number
 from pathlib import Path
