@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 __all__ = [
     "path_to_str",
     "get_file_name",
@@ -48,6 +50,10 @@ from lt_utils.type_utils import (
     is_str,
     is_file_format,
 )
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from pandas import DataFrame
 
 
 def get_file_name(entry: PathLike, keep_extension: bool = True):
@@ -58,8 +64,9 @@ def get_file_name(entry: PathLike, keep_extension: bool = True):
     return f_name[: f_name.rfind(".")]
 
 
-def path_to_str(entry: PathLike):
-    is_pathlike(entry, False, True)
+def path_to_str(entry: PathLike, *, check: bool = True):
+    if check:
+        is_pathlike(entry, False, True)
     return str(entry).replace("\\", "/")
 
 
@@ -117,7 +124,7 @@ class FileScan:
             for path in gen_fn:
                 if not eval_fn(path):
                     continue
-                results.append(path_to_str(path))
+                results.append(path_to_str(path, check=False))
                 found += 1
                 if maximum <= found:
                     return sorted(results)
@@ -448,62 +455,187 @@ def get_disk_usage(path: PathLike = ".", validate: bool = False) -> dict:
     return {"total": usage.total, "used": usage.used, "free": usage.free}
 
 
-def save_dataframe(path: PathLike, content: object):
+def _retrieve_kwargs(valid_kwargs: List[str], **kwargs):
+    """Helper for setting up kwargs"""
+    validated_kwargs = {}
+    for k in valid_kwargs:
+        if k in kwargs:
+            validated_kwargs[k] = kwargs[k]
+    return validated_kwargs
+
+
+def save_dataframe(
+    path: PathLike,
+    content: "DataFrame",
+    *args,
+    **kwargs,
+):
     """Save a DataFrame to a file. Supports .csv and .parquet extensions."""
-    is_pathlike(path, True, True)
-    is_file_format(path, [".csv", ".parquet"], True)
-    if Path(path).name.endswith(".csv"):
-        content.to_csv(path, index=False)
+
+    is_pathlike(path, True, validate=True)
+    is_file_format(
+        path,
+        [".csv", ".tsv", ".parquet", ".json", ".npy", ".pkl"],
+        validate=True,
+    )
+
+    # : [\w\s\t\d|\.,\[\]'"=]+[,]?
+    path_name = Path(path).name
+    if path_name.endswith((".csv", ".tsv")):
+        content.to_csv(
+            str(path),
+            **_retrieve_kwargs(
+                [
+                    "sep",
+                    "na_rep",
+                    "float_format",
+                    "columns",
+                    "header",
+                    "index",
+                    "index_label",
+                    "mode",
+                    "encoding",
+                    "compression",
+                    "quoting",
+                    "quotechar",
+                    "lineterminator",
+                    "chunksize",
+                    "date_format",
+                    "doublequote",
+                    "escapechar",
+                    "decimal",
+                    "errors",
+                    "storage_options",
+                ],
+                kwargs=kwargs,
+            ),
+        )
+    elif path_name.endswith(".json"):
+        content.to_json(
+            str(path),
+            **_retrieve_kwargs(
+                [
+                    "orient",
+                    "date_format",
+                    "double_precision",
+                    "force_ascii",
+                    "date_unit",
+                    "default_handler",
+                    "line",
+                    "compression",
+                    "index",
+                    "indent",
+                    "mode",
+                ],
+                kwargs=kwargs,
+            ),
+        )
+    elif path_name.endswith(".parquet"):
+        content.to_parquet(
+            str(path),
+            **_retrieve_kwargs(
+                [
+                    "engine",
+                    "compression",
+                    "index",
+                    "partition_cols",
+                    "storage_options",
+                ],
+                kwargs=kwargs,
+            ),
+        )
+    elif path_name.endswith(".pkl"):
+        content.to_pickle(
+            str(path),
+            **_retrieve_kwargs(
+                ["protocol", "compression", "storage_options"],
+                kwargs=kwargs,
+            ),
+        )
     else:
-        content.to_parquet(path, index=False)
+        import numpy as np
+
+        content_array = content.to_numpy(
+            path,
+            **_retrieve_kwargs(
+                ["copy", "na_value"],
+                kwargs=kwargs,
+            ),
+        )
+        np.save(str(path), content_array, allow_pickle=kwargs.get("allow_pickle", True))
 
 
-def load_dataframe(path: PathLike, default_value: Optional[Any] = None):
+def load_dataframe(
+    path: Optional[PathLike] = None,
+    default_value: Optional[Any] = None,
+    *args,
+    **kwargs,
+):
     """Load a DataFrame from a .csv or .parquet file."""
     import pandas as pd
 
-    is_file_format(path, [".csv", ".parquet"], True)
     if not is_file(path, validate=default_value is None):
         return default_value
-    if Path(path).name.endswith(".csv"):
-        return pd.read_csv(path)
 
-    return pd.read_parquet(path)
+    file_type = Path(path).name
+
+    is_file_format(path, [".csv", ".tsv", ".parquet", ".json"], validate=True)
+    data = Path(path).read_bytes()
+
+    if file_type.endswith((".csv", ".tsv")):
+        return pd.read_csv(path, **kwargs)
+    if file_type.endswith(".json"):
+        return pd.read_json(path, **kwargs)
+    return pd.read_parquet(path, *args, **kwargs)
+
+
+def save_pickle(
+    path: Union[PathLike, str],
+    content: object,
+    errors: Optional[str] = None,
+    protocol=None,
+):
+    """Save any Python object to a pickle file."""
+    is_pathlike(path, True, True)
+    path = Path(path)
+    path.parent.mkdir(exist_ok=True, parents=True)
+    if path.name.endswith(".npy"):
+        import numpy as np
+
+        np.save(str(path), content, allow_pickle=True)
+    else:
+        import pickle
+
+        with open(str(path), "wb", errors=errors) as f:
+            pickle.dump(content, f, protocol=protocol)
 
 
 def load_pickle(
     path: Union[PathLike, str],
     default: Optional[Any] = None,
     encoding: Optional[
-        Union[str, Literal["utf-8", "ascii", "unicode-escape", "latin-1"]]
-    ] = None,
+        Union[str, Literal["utf-8", "ascii", "unicode-escape", "latin-1", "bytes"]]
+    ] = "utf-8",
     errors: Union[str, Literal["strict", "ignore"]] = "strict",
+    mmap_mode: Literal["r+", "r", "w+", "c"] | None = None,
 ):
     """Load a Python object from a pickle file."""
-    import pickle
-
     if not is_file(path, validate=default is None):
         return default
+    path_name = Path(path).name
+    if path_name.endswith(".npy"):
+        import numpy as np
 
-    with open(path, "rb", encoding=encoding) as f:
-        return pickle.load(f, encoding=encoding, errors=errors)
+        return np.load(
+            str(path),
+            mmap_mode=mmap_mode,
+            allow_pickle=True,
+        )
 
-
-def save_pickle(
-    path: Union[PathLike, str],
-    content: object,
-    encoding: Optional[
-        Union[str, Literal["utf-8", "ascii", "unicode-escape", "latin-1"]]
-    ] = None,
-):
-    """Save any Python object to a pickle file."""
     import pickle
 
-    is_pathlike(path, True, True)
-    Path(path).parent.mkdir(exist_ok=True, parents=True)
-
-    with open(str(path), "wb", encoding=encoding) as f:
-        pickle.dump(content, f)
+    with open(path, "rb") as f:
+        return pickle.load(f, encoding=encoding, errors=errors)
 
 
 def load_json(
@@ -511,7 +643,7 @@ def load_json(
     default: Optional[Any] = None,
     encoding: Optional[
         Union[str, Literal["utf-8", "ascii", "unicode-escape", "latin-1"]]
-    ] = None,
+    ] = "utf-8",
     errors: Union[str, Literal["strict", "ignore"]] = "strict",
 ) -> Union[list, dict]:
     """
@@ -549,7 +681,7 @@ def save_json(
     *,
     encoding: Optional[
         Union[str, Literal["utf-8", "ascii", "unicode-escape", "latin-1"]]
-    ] = None,
+    ] = "utf-8",
     errors: Union[str, Literal["strict", "ignore"]] = "strict",
     skipkeys: bool = False,
     ensure_ascii: bool = True,
@@ -601,7 +733,7 @@ def load_text(
     *,
     encoding: Optional[
         Union[str, Literal["utf-8", "ascii", "unicode-escape", "latin-1"]]
-    ] = None,
+    ] = "utf-8",
     errors: Union[str, Literal["strict", "ignore"]] = "strict",
     default_value: Optional[Any] = None,
 ) -> str:
@@ -616,7 +748,7 @@ def save_text(
     *,
     encoding: Optional[
         Union[str, Literal["utf-8", "ascii", "unicode-escape", "latin-1"]]
-    ] = None,
+    ] = "utf-8",
     errors: Union[str, Literal["strict", "ignore"]] = "strict",
     newline: Optional[str] = None,
 ) -> None:
@@ -677,7 +809,8 @@ def save_yaml(
     import yaml
 
     is_pathlike(path, True, True)
-    Path(path).parent.mkdir(exist_ok=True, parents=True)
+    path = Path(path)
+    path.parent.mkdir(exist_ok=True, parents=True)
 
     save_func = yaml.safe_dump if safe_dump else yaml.dump
     data = save_func(data=content, stream=None, encoding=encoding)
