@@ -16,12 +16,11 @@ __all__ = [
     "lemmatize_text",
     "generate_ngrams",
     "max_rfinder",
-    "check_next_string",
+    "check_next",
     "trim_incomplete_sentence",
     "simplify_quotes",
     "clear_empty",
     "extract_named_entities",
-    "delimiter_split",
     "find_repeated_words",
     "normalize_text",
     "remove_non_printable",
@@ -33,11 +32,12 @@ __all__ = [
     "formatter",
     "count_words",
     "extract_keys",
-    "find_in_text",
+    "has_any",
     "unescape",
     "escape",
     "replace_pos_tags",
     "requoter",
+    "fragment_text",
 ]
 
 import gc
@@ -142,7 +142,10 @@ def similarity(
 
 
 def has_digit(text: str):
-    return any([x.isdigit() for x in text.strip()])
+    for char in text.strip():
+        if char.isdigit():  # faster to give up once found
+            return True
+    return False
 
 
 def entropy(
@@ -187,11 +190,12 @@ def entropy(
     return float(ent)
 
 
-def scramble_text(text: str) -> str:
+def scramble_text(text: str, seed: Optional[int] = None) -> str:
     """Randomly shuffle the words in a text.
 
     Args:
         text (str): The input text to be scrambled.
+        seed (int, optional): Seed for reproducing the results
 
     Returns:
         str: The text with its words randomly shuffled.
@@ -199,6 +203,8 @@ def scramble_text(text: str) -> str:
     import random
 
     words = text.split()
+    if seed is not None:
+        random.seed(seed)
     random.shuffle(words)
     return " ".join(words)
 
@@ -278,7 +284,7 @@ def clipboard(
 
 
 def html_to_markdown(
-    html: AnyStr,
+    html: Union[str, bytes],
     escape_asterisks: bool = True,
     escape_underscores: bool = True,
     escape_misc: bool = True,
@@ -316,7 +322,7 @@ def html_to_markdown(
     )
 
 
-def markdown_to_html(markdown: AnyStr) -> str:
+def markdown_to_html(markdown: Union[str, bytes]) -> str:
     """
     Converts Markdown text to HTML.
 
@@ -361,9 +367,6 @@ def _blob_split(text: str, *, __recall: bool = False) -> List[str]:
         raise e
 
 
-_split_scan = SplitText()
-
-
 def split(
     entry: str,
     max_length: int = 200,
@@ -395,7 +398,7 @@ def split(
     if simplify_quote:
         entry = simplify_quotes(entry)
     if mode == "base":
-        return _split_scan(
+        return SplitText()(
             entry,
             desired_length=desired_length,
             max_length=max_length,
@@ -481,7 +484,7 @@ def max_rfinder(entry: str, items_to_find: Union[List[str], Tuple[str, ...]]):
     return highest_results
 
 
-def check_next_string(
+def check_next(
     entry: str,
     current_id: int,
     text_to_match: str | list[str] | None = None,
@@ -599,19 +602,6 @@ def extract_named_entities(
     )
 
 
-def delimiter_split(text: str, delimiter: str) -> List[str]:
-    """Splits text into parts based on a delimiter.
-
-    Args:
-        text (str): The input text to be chunked.
-        delimiter (str): The delimiter to use for splitting the text.
-
-    Returns:
-        List[str]: A list of text chunks.
-    """
-    return text.split(delimiter)
-
-
 def find_repeated_words(text: str, language: str = "english") -> Dict[str, int]:
     """Find and count repeated words in a text.
 
@@ -796,42 +786,39 @@ def extract_keys(entry: str) -> list | list[str]:
     return keys
 
 
-def find_in_text(
+def has_any(
     entry: str,
-    has_any: Union[str, Sequence[str]],
+    any_of: Union[str, List[str]],
     force_lower_case: bool = False,
 ):
-    """Basically the reverse of **in** function, it can be used to locate if **sources** contains anything from the **has_any** into it.
+    """Basically the reverse of **in** function, it can be used to locate if **sources** contains anything from the **any_of** into it.
 
     Args:
         sources (str):
             Target string to be checked if has any of the provided keys.
-        has_any (str | list[str]):
+        any_of (str | list[str]):
             The string or list of strings to be checked if they are or not in the text.
             If its a string each letter will be checked, if its a list of string, then each word in the list will be checked instead.
         force_lower_case (bool, optional):
-            If true will set everything to lower-case (both source and has_any).
+            If true will set everything to lower-case (both source and any_of).
             This is useful for tasks that dont require a case-sensitive scan. Defaults to False.
 
     Returns:
         bool: If any key was found will be returned as true, otherwise False.
     """
-    if not entry or not has_any:
+    if not entry or not isinstance(any_of, (str, tuple, list)) or not any_of:
         return False
 
-    if isinstance(has_any, (list, tuple)) and has_any:
-        has_any = [
-            x.lower() if force_lower_case else x for x in has_any if isinstance(x, str)
+    if isinstance(any_of, (list, tuple)):
+        any_of = [
+            x.lower() if force_lower_case else x for x in any_of if isinstance(x, str)
         ]
-        if not has_any:
+        if not any_of:
             return False
+    else:
+        any_of = [any_of.lower() if force_lower_case else any_of]
 
-    if force_lower_case:
-        entry = entry.lower()
-        if is_str(has_any):
-            has_any = has_any.lower()  # type: ignore
-
-    for elem in has_any:
+    for elem in any_of:
         if elem in entry:
             return True
     return False
@@ -874,9 +861,9 @@ def unescape(
 def escape(
     entry: Union[str, bytes],
     errors: Literal["strict", "ignore"] = "strict",
-    encoding: Optional[
-        Union[str, Literal["utf-8", "ascii", "unicode-escape", "latin-1"]]
-    ] = None,
+    encoding: Union[
+        str, Literal["utf-8", "ascii", "unicode-escape", "latin-1"]
+    ] = "utf-8",
 ) -> Union[str, bytes]:
     """
     Escapes the given string.
@@ -911,36 +898,6 @@ def escape(
     )
 
 
-def _fix_lines_structure(entry: str, sep: str = "\n\n"):
-    """Wip function, not fully tested."""
-    results = []
-    # is_on_sentence:bool = False
-    was_on_break_dot: bool = False
-    current_sentence = []
-    entry = re.sub(r"\n+", " ", entry)
-    entry = re.sub(r"\s+", " ", entry)
-    entry = re.sub(r"[\t\r\v\f]+", " ", entry)
-    for char in entry:
-        if char == " ":
-            if was_on_break_dot:
-                if current_sentence:
-                    results.append("".join(current_sentence))
-                current_sentence.clear()
-                was_on_break_dot = False
-            else:
-                current_sentence.append(char)
-        elif char == ".":
-            was_on_break_dot = True
-            current_sentence.append(char)
-        else:
-            was_on_break_dot = False
-            current_sentence.append(char)
-    if current_sentence:
-        results.append("".join(current_sentence))
-
-    return sep.join(results)
-
-
 def replace_pos_tags(
     entry: str,
     target_pos_tags: List[str],
@@ -991,3 +948,34 @@ def replace_pos_tags(
     }
 
     return recursive_replacer(entry, replacers) if replacers else entry
+
+
+def fragment_text(
+    text: Union[str, List[str]],
+    prob: float = 0.3,
+    sizes: List[int] = [2, 3, 4, 5],
+    seed: Optional[int] = None,
+):
+    """Break a word into small fragments with some probability."""
+    import random
+
+    if isinstance(text, str):
+        results = [text]
+    if len(text) <= min(sizes):
+        return results
+    # simple split: half
+    mid = len(text) // 2
+    results.append(text[:mid])
+    results.append(text[mid:])
+
+    # n-grams
+    if seed is not None:
+        random.seed(seed)
+    for n in sizes:
+        if n >= mid:
+            break
+        if len(text) >= n:
+            for i in range(len(text) - n + 1):
+                if random.random() < prob:
+                    results.append(text[i : i + n])
+    return list(set(results))
